@@ -17,10 +17,10 @@ class RedisConsumer(AbstractConsumer, RedisMixin):
     def _shedual_task(self):
         while True:
             t_start = time.time()
-            task_bytes = self.redis_db_frame.blpop(self._queue_name)[1]
-            if task_bytes:
-                self.logger.debug(f'取出的任务时间是 {round(time.time() - t_start, 4)}    消息是：  {task_bytes.decode()}  ')
-                task_dict = json.loads(task_bytes)
+            result = self.redis_db_frame.blpop(self._queue_name,timeout=60)
+            if result:
+                self.logger.debug(f'取出的任务时间是 {round(time.time() - t_start, 4)}    消息是：  {result[1].decode()}  ')
+                task_dict = json.loads(result[1])
                 kw = {'body': task_dict}
                 self._submit_task(kw)
 
