@@ -17,3 +17,10 @@ REDIS_HOST = '127.0.0.1'
 REDIS_PASSWORD = 'redis_password'
 REDIS_PORT = 6379
 REDIS_DB = 7
+
+NSQD_TCP_ADDRESSES = ['127.0.0.1:4150']
+NSQD_HTTP_CLIENT_HOST = '127.0.0.1'
+NSQD_HTTP_CLIENT_PORT = 4151
+
+
+KAFKA_BOOTSTRAP_SERVERS=['127.0.0.1:9092']
\ No newline at end of file
