@@ -10,6 +10,7 @@ concurrent_log_handler的ConcurrentRotatingFileHandler解决了logging模块自
 3、支持pycharm点击日志跳转到对应代码文件的对应行。
 4、对相同命名空间的logger可以无限添加同种类型的handlers，不会重复使用同种handler记录日志。不需要用户自己去判断。
 
+
 """
 import socket
 import datetime
@@ -21,6 +22,7 @@ import unittest
 import time
 from collections import OrderedDict
 from queue import Queue
+# noinspection PyPackageRequirements
 from kafka import KafkaProducer
 from elasticsearch import Elasticsearch, helpers
 from threading import Lock, Thread
@@ -30,7 +32,6 @@ import logging
 from logging import handlers
 from concurrent_log_handler import ConcurrentRotatingFileHandler  # 需要安装。concurrent-log-handler==0.9.1
 
-
 os_name = os.name
 
 DING_TALK_TOKEN = '3dd0ee497f0xxx'  # 钉钉报警机器人
@@ -47,7 +48,8 @@ KAFKA_BOOTSTRAP_SERVERS = ['192.xx.xx.202:9092']
 ALWAYS_ADD_KAFKA_HANDLER_IN_TEST_ENVIRONENT = True
 
 
-class app_config:  # 由于日志引用导入了app.config as app_config，此处模拟模块级的配置，实际代码不是这样。
+# noinspection PyPep8Naming
+class app_config:  # 由于日志引用导入了app.config as app_config，此处模拟模块级的配置，实际代码不是这样。类名用了小写是为了不想修改多个地方兼容。
     env = 'production'
     connect_url = 'mongo://xxx'  # mongo连接
 
@@ -64,10 +66,12 @@ def very_nb_print(*args, sep=' ', end='\n', file=None):
     # 获取被调用函数所在模块文件名
     file_name = sys._getframe(1).f_code.co_filename
     # sys.stdout.write(f'"{__file__}:{sys._getframe().f_lineno}"    {x}\n')
-    args = (str(arg) for arg in args)  # REMIND 防止是数字不能被join
+    args = (str(arg) for arg in args)  # REMIND 防止是数字或其他类型对象不能被join
     sys.stdout.write(f'"{file_name}:{line}"  {time.strftime("%H:%M:%S")}  \033[0;94m{"".join(args)}\033[0m\n')  # 36  93 96 94
 
 
+# print = very_nb_print
+
 def revision_call_handlers(self, record):  # 对logging标准模块打猴子补丁。主要是使父命名空间的handler不重复记录当前命名空间日志已有种类的handler。
     """
     重要。这可以使同名logger或父logger随意添加同种类型的handler，确保不会重复打印。
@@ -118,7 +122,6 @@ def revision_call_handlers(self, record):  # 对logging标准模块打猴子补
 logging.Logger.callHandlers = revision_call_handlers  # 打猴子补丁。
 
 # noinspection PyShadowingBuiltins
-# print = very_nb_print
 formatter_dict = {
     1: logging.Formatter(
         '日志时间【%(asctime)s】 - 日志名称【%(name)s】 - 文件【%(filename)s】 - 第【%(lineno)d】行 - 日志等级【%(levelname)s】 - 日志信息【%(message)s】',
@@ -1321,7 +1324,7 @@ class _Test(unittest.TestCase):
         # logger = LogManager('helloMongo', is_pycharm_2019=False).get_logger_and_add_handlers(mongo_url=app_config.connect_url, formatter_template=5)
         logging.error('xxxx')
         logger = LogManager('helloMongo', is_pycharm_2019=False).get_logger_and_add_handlers(formatter_template=5)
-        logger.addHandler(ColorHandler())    # 由于打了强大的猴子补丁，无惧反复添加同种handler。
+        logger.addHandler(ColorHandler())  # 由于打了强大的猴子补丁，无惧反复添加同种handler。
         logger.addHandler(ColorHandler())
         logger.addHandler(ColorHandler())
         for i in range(1000000):
